"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
// import css
require("../../../../css/margins.css");
require("../../../../css/filter_modal.css");
/*
Implementation plan:
- There is a set of displayed filters, but they are not the set of applied filters.
- The displayed filters D, are a superset of the applied filters F.
- The applied fitlers, F, are D - the filters that have _no_ text in them. We only apply a filters
  with something in them
*/
var SharedFilterCondition;
(function (SharedFilterCondition) {
    SharedFilterCondition["EMPTY"] = "empty";
    SharedFilterCondition["NOT_EMPTY"] = "not_empty";
})(SharedFilterCondition = exports.SharedFilterCondition || (exports.SharedFilterCondition = {}));
var StringFilterCondition;
(function (StringFilterCondition) {
    StringFilterCondition["CONTAINS"] = "contains";
    StringFilterCondition["DOES_NOT_CONTAIN"] = "string_does_not_contain";
    StringFilterCondition["STRING_EXACTLY"] = "string_exactly";
})(StringFilterCondition = exports.StringFilterCondition || (exports.StringFilterCondition = {}));
var NumberFilterCondition;
(function (NumberFilterCondition) {
    NumberFilterCondition["NUMBER_EXACTLY"] = "number_exactly";
    NumberFilterCondition["GREATER"] = "greater";
    NumberFilterCondition["GREATER_THAN_OR_EQUAL"] = "greater_than_or_equal";
    NumberFilterCondition["LESS"] = "less";
    NumberFilterCondition["LESS_THAN_OR_EQUAL"] = "less_than_or_equal";
})(NumberFilterCondition = exports.NumberFilterCondition || (exports.NumberFilterCondition = {}));
var DateFilterCondition;
(function (DateFilterCondition) {
    DateFilterCondition["DATETIME_EXTACTLY"] = "datetime_exactly";
    DateFilterCondition["DATETIME_GREATER_THAN"] = "datetime_greater";
    DateFilterCondition["DATETIME_GREATER_THAN_OR_EQUAL"] = "datetime_greater_than_or_equal";
    DateFilterCondition["DATETIME_LESS"] = "datetime_less";
    DateFilterCondition["DATETIME_LESS_THAN_OR_EQUAL"] = "datetime_less_than_or_equal";
})(DateFilterCondition = exports.DateFilterCondition || (exports.DateFilterCondition = {}));
// if one of these filters are selected, don't display the value input
const noInputFilters = [SharedFilterCondition.EMPTY, SharedFilterCondition.NOT_EMPTY];
const getNumberDropdownOptions = () => {
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("option", { value: NumberFilterCondition.NUMBER_EXACTLY }, "="),
        react_1.default.createElement("option", { value: NumberFilterCondition.GREATER }, ">"),
        react_1.default.createElement("option", { value: NumberFilterCondition.GREATER_THAN_OR_EQUAL }, "\u2265"),
        react_1.default.createElement("option", { value: NumberFilterCondition.LESS }, "<"),
        react_1.default.createElement("option", { value: NumberFilterCondition.LESS_THAN_OR_EQUAL }, "\u2264")));
};
const getStringDropdownOptions = () => {
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("option", { value: StringFilterCondition.CONTAINS }, "contains"),
        react_1.default.createElement("option", { value: StringFilterCondition.DOES_NOT_CONTAIN }, "does not contain"),
        react_1.default.createElement("option", { value: StringFilterCondition.STRING_EXACTLY }, "is exactly")));
};
const getDatetimeDropdownOptions = () => {
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("option", { value: DateFilterCondition.DATETIME_EXTACTLY }, "="),
        react_1.default.createElement("option", { value: DateFilterCondition.DATETIME_GREATER_THAN }, ">"),
        react_1.default.createElement("option", { value: DateFilterCondition.DATETIME_GREATER_THAN_OR_EQUAL }, "\u2265"),
        react_1.default.createElement("option", { value: DateFilterCondition.DATETIME_LESS }, "<"),
        react_1.default.createElement("option", { value: DateFilterCondition.DATETIME_LESS_THAN_OR_EQUAL }, "\u2264")));
};
const getSharedDropdownOptions = () => {
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("option", { value: SharedFilterCondition.EMPTY }, "is empty"),
        react_1.default.createElement("option", { value: SharedFilterCondition.NOT_EMPTY }, "is not empty")));
};
const getNewEmptyFilter = (columnType) => {
    switch (columnType) {
        case 'string':
            return {
                type: 'string',
                condition: StringFilterCondition.CONTAINS,
                value: ''
            };
        case 'number':
            return {
                type: 'number',
                condition: NumberFilterCondition.NUMBER_EXACTLY,
                value: ''
            };
        case 'datetime':
            return {
                type: 'datetime',
                condition: DateFilterCondition.DATETIME_EXTACTLY,
                value: ''
            };
    }
};
/*
    A modal that allows a user to filter a column
*/
class FilterCard extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.state = {
            displayedFilters: this.props.filters,
            operator: this.props.operator,
            stepID: ''
        };
        this.buildFilters = this.buildFilters.bind(this);
        this.sendFilterUpdateMessage = this.sendFilterUpdateMessage.bind(this);
    }
    sendFilterUpdateMessage() {
        return __awaiter(this, void 0, void 0, function* () {
            // Before sending the displayed filters, we:
            // 1. Change all undefined values (like this in conditions without values) to 0's,
            // 2. Filter out all the filters that have an empty string as the value
            const filtersToApply = this.state.displayedFilters.map(filter => {
                return {
                    'type': filter.type,
                    'condition': filter.condition,
                    'value': filter.value === undefined ? 0 : filter.value
                };
            }).filter(filter => {
                return filter['value'] !== '';
            });
            const stepID = yield this.props.mitoAPI.sendFilterMessage(this.props.selectedSheetIndex, this.props.columnHeader, filtersToApply, this.state.operator, this.state.stepID);
            this.setState({ stepID: stepID });
        });
    }
    /*
        Builds all the JSX for the filter selections, for all of the filters in
        this.state.filters
    */
    buildFilters() {
        /*
            Occurs when the user changes what operator is operating
            on the filter conditions.
        */
        const handleToggleOperator = (e) => {
            const newOperator = e.target.value;
            this.setState({
                operator: newOperator
            }, () => {
                void this.sendFilterUpdateMessage();
            });
        };
        /*
            A helper function to update the filter condition for a specific index
        */
        const handleConditionChange = (filterIndex, e) => {
            // This case is safe, as users can only select from a list of the enum
            const newCondition = e.target.value;
            this.setState(prevState => {
                const newFilters = [...prevState.displayedFilters];
                newFilters[filterIndex].condition = newCondition;
                if (noInputFilters.includes(newCondition)) {
                    // Clear the value, if this condition has no value
                    newFilters[filterIndex].value = undefined;
                }
                else {
                    // Otherwise, set it to the empty string, if it does not have a value current
                    if (newFilters[filterIndex].value === undefined) {
                        newFilters[filterIndex].value = '';
                    }
                }
                return { displayedFilters: newFilters };
            }, () => {
                // once state is updated, send the filter message
                void this.sendFilterUpdateMessage();
            });
        };
        /*
            Occurs when the user  changes the
        */
        const handleValueChange = (filterIndex, e) => {
            // Occurs when the user changes a value on a specific filter, which is then
            // saved to the state for this filter
            const filter = this.state.displayedFilters[filterIndex];
            let newValue = e.target.value;
            // Cast it to the correct type, aka turn it to a number if this is a number filter
            if (filter.type === 'number') {
                const float = parseFloat(newValue);
                if (!Number.isNaN(float)) {
                    newValue = float;
                }
            }
            this.setState(prevState => {
                const newFilters = [...prevState.displayedFilters];
                // Note: we save the new condition outside the setState, as react does
                // not keep events around! 
                newFilters[filterIndex].value = newValue;
                return {
                    displayedFilters: newFilters,
                };
            }, () => {
                // once state is updated, try sending the filter message
                void this.sendFilterUpdateMessage();
            });
        };
        const removeFilter = (filterIndex) => {
            // Removes the filter at the given filterIndex 
            this.setState(prevState => {
                const newFilters = [...prevState.displayedFilters];
                newFilters.splice(filterIndex, 1);
                return {
                    displayedFilters: newFilters
                };
            }, () => {
                // once state is updated, try sending the filter message
                void this.sendFilterUpdateMessage();
            });
        };
        const getFilter = (filter, filterIndex) => {
            // Builds the table row element for a given filter at a given index
            var _a;
            // We use styles to hide divs we don't want, to keep the spacing the same
            const operatorStyle = filterIndex === 0 ? { visibility: 'hidden' } : { visibility: 'visible' };
            const inputStyle = noInputFilters.includes(filter.condition) ? { visibility: 'hidden' } : { visibility: 'visible' };
            return (react_1.default.createElement(react_1.default.Fragment, { key: filterIndex },
                react_1.default.createElement("tr", null,
                    react_1.default.createElement("td", null,
                        react_1.default.createElement("select", { className: 'select filter-modal-input', style: operatorStyle, value: this.state.operator, onChange: handleToggleOperator },
                            react_1.default.createElement("option", { value: 'And' }, "And"),
                            react_1.default.createElement("option", { value: 'Or' }, "Or"))),
                    react_1.default.createElement("td", null,
                        react_1.default.createElement("select", { className: "select filter-modal-condition-select", value: filter.condition, onChange: e => handleConditionChange(filterIndex, e) },
                            filter.type === 'number' && getNumberDropdownOptions(),
                            filter.type === 'string' && getStringDropdownOptions(),
                            filter.type === 'datetime' && getDatetimeDropdownOptions(),
                            getSharedDropdownOptions())),
                    react_1.default.createElement("td", null,
                        react_1.default.createElement("input", { type: filter.type === 'datetime' ? 'date' : 'text', className: "input filter-modal-value-input", style: inputStyle, value: (_a = filter.value) === null || _a === void 0 ? void 0 : _a.toString(), onChange: e => handleValueChange(filterIndex, e) })),
                    react_1.default.createElement("td", null,
                        react_1.default.createElement("div", { className: 'ml-1 mr-1', onClick: () => removeFilter(filterIndex) },
                            react_1.default.createElement("svg", { width: "13", height: "3", viewBox: "0 0 13 3", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
                                react_1.default.createElement("rect", { width: "13", height: "3", rx: "1", fill: "#B1B1B1" })))))));
        };
        return (react_1.default.createElement("table", null,
            react_1.default.createElement("tbody", null,
                this.state.displayedFilters.length > 0 &&
                    react_1.default.createElement("tr", null,
                        react_1.default.createElement("td", null),
                        react_1.default.createElement("td", null, "Filter Condition"),
                        react_1.default.createElement("td", null, "Value")),
                this.state.displayedFilters.map((filter, filterIndex) => {
                    return getFilter(filter, filterIndex);
                }))));
    }
    render() {
        const addFilter = () => {
            this.setState(prevState => {
                const newFilters = [...prevState.displayedFilters];
                newFilters.push(getNewEmptyFilter(this.props.columnType));
                return {
                    displayedFilters: newFilters
                };
            }, () => {
                void this.sendFilterUpdateMessage();
            });
        };
        return (react_1.default.createElement("div", null,
            react_1.default.createElement("div", { className: 'filter-modal-section-title filter-modal-section-spacer' },
                react_1.default.createElement("p", null, " Filter ")),
            react_1.default.createElement("div", { className: "filter-modal-centering-container" },
                this.state.displayedFilters.length === 0 &&
                    react_1.default.createElement("p", { className: 'mb-1' }, "Hit the Add Filter button below to begin filtering this column."),
                this.buildFilters(),
                react_1.default.createElement("div", { className: 'filter-modal-add-value', onClick: addFilter }, "+ Add Filter"))));
    }
}
exports.default = FilterCard;
//# sourceMappingURL=FilterCard.js.map