"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("@jupyter-widgets/base");
const version_1 = require("./version");
// React
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
// Components
const Mito_1 = __importDefault(require("./components/Mito"));
class ExampleModel extends base_1.DOMWidgetModel {
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: ExampleModel.model_name, _model_module: ExampleModel.model_module, _model_module_version: ExampleModel.model_module_version, _view_name: ExampleModel.view_name, _view_module: ExampleModel.view_module, _view_module_version: ExampleModel.view_module_version, df_json: '' });
    }
}
exports.ExampleModel = ExampleModel;
ExampleModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
ExampleModel.model_name = 'ExampleModel';
ExampleModel.model_module = version_1.MODULE_NAME;
ExampleModel.model_module_version = version_1.MODULE_VERSION;
ExampleModel.view_name = 'ExampleView'; // Set to null if no view
ExampleModel.view_module = version_1.MODULE_NAME; // Set to null if no view
ExampleModel.view_module_version = version_1.MODULE_VERSION;
const Mito_2 = require("./components/Mito");
const gridStyling_1 = require("./utils/gridStyling");
const api_1 = require("./api");
class ExampleView extends base_1.DOMWidgetView {
    /*
    We override the DOMWidgetView constructor, so that we can
    create a logging instance for this view.
  */
    initialize(parameters) {
        super.initialize(parameters);
        // We get the user id from the client side
        window.user_id = this.model.get('user_id');
    }
    /*
    We override the sending message utilities
  */
    send(msg) {
        var _a, _b;
        // If this is a message that makes a change (anything but a log_event or api_call or has_rendered_update),
        // then we make the system as loading, as we wait for a response
        if (msg['event'] !== 'log_event' && msg['event'] !== 'api_call' && msg['type'] !== 'has_rendered_update') {
            (_b = (_a = window.mitoMap) === null || _a === void 0 ? void 0 : _a.get(this.model.model_id)) === null || _b === void 0 ? void 0 : _b.setState({
                loading: true
            });
        }
        super.send(msg);
    }
    render() {
        var _a, _b;
        // Capture the send, to pass to the component
        const send = (msg) => {
            this.send(msg);
        };
        // TODO: there is a memory leak, in the case where
        // we rerender the component (e.g. we run the mito.sheet)
        // cell again. We need to clean up the component somehow!
        const model_id = this.model.model_id;
        const mitoAPI = new api_1.MitoAPI(send);
        react_dom_1.default.render(react_1.default.createElement(Mito_1.default, { mitoAPI: mitoAPI, dfNames: this.getDfNames(), sheetShapeArray: this.getSheetShapeArray(), sheetJSONArray: this.getSheetJSONArray(), columnSpreadsheetCodeJSONArray: this.getColumnSpreadsheetCodeJSONArray(), savedAnalysisNames: this.getSavedAnalysisNames(), columnFiltersArray: this.getColumnFilters(), columnTypeJSONArray: this.getColumnTypeJSONArray(), tutorialMode: this.getTutorialMode(), model_id: model_id, isLocalDeployment: this.getIsLocalDeployment(), ref: (Mito) => {
                // The first time we render the item, register the Mito instance
                if (window.mitoMap === undefined) {
                    window.mitoMap = new Map();
                }
                window.mitoMap.set(model_id, Mito);
                // We also register the API for this Mito instance
                if (window.mitoAPIMap === undefined) {
                    window.mitoAPIMap = new Map();
                }
                window.mitoAPIMap.set(model_id, mitoAPI);
            } }), this.el);
        this.model.on('msg:custom', this.handleMessage, this);
        /*
        The first render of a widget happens when the mitosheet.sheet call is
        run. It does not occur when the page that this widget on is refreshed.
        
        We only need to send update events for df_names and reading an existing analysis
        in the case that this is the first render, and not when the page is refreshed.

        NOTE: Rerunning a mitosheet.sheet call that has an analysis in the cell
        below is _creating a new mitosheet_. Thus, this.getHasRendered() will
        return false in this case.
    */
        if (!this.getHasRendered()) {
            // Get df name from code block, and pass it to both the frontend and the backend
            (_a = window.commands) === null || _a === void 0 ? void 0 : _a.execute('get-df-names').then((dfNames) => {
                // If there are dataframe names, send them to the backend
                if (dfNames.length > 0) {
                    this.send({
                        'event': 'update_event',
                        'type': 'df_names_update',
                        'df_names': dfNames
                    });
                }
            });
            // Get any previous analysis and send it back to the model!
            (_b = window.commands) === null || _b === void 0 ? void 0 : _b.execute('read-existing-analysis').then((analysisName) => __awaiter(this, void 0, void 0, function* () {
                // If there is no previous analysis, we just ignore this step
                if (!analysisName)
                    return;
                // We log that we read from below
                yield mitoAPI.sendLogMessage('read_analysis_from_cell_below', {
                    analysis_name: analysisName
                });
                // And send it to the backend (we don't care when it terminates)
                yield mitoAPI.sendUseExistingAnalysisUpdateMessage(analysisName, undefined, 
                /*
                    When we read in an analysis name from a cell, we replay this analysis
                    while also overwriting _everything_ that is already in the analysis.

                    This is to avoid issues w/ passing in a saved analysis to the mitosheet.sheet
                    call, where then rerunning the cell with this call w/ doubly-apply things.
                */
                true);
            }));
        }
        // Let the backend know we have now rendered the sheet, and all future
        // renders therefor must be page refreshes, and so we let the backend 
        // know that we have rendered
        this.send({
            'event': 'update_event',
            'type': 'has_rendered_update'
        });
    }
    getHasRendered() {
        return this.model.get('has_rendered');
    }
    getSheetJSONArray() {
        const sheetJSONArray = [];
        try {
            const modelSheetJSONArray = JSON.parse(this.model.get('sheet_json'));
            sheetJSONArray.push(...modelSheetJSONArray);
        }
        catch (e) {
            // Suppress error
            console.error(e);
        }
        return sheetJSONArray;
    }
    getIsLocalDeployment() {
        return this.model.get('is_local_deployment');
    }
    getSheetShapeArray() {
        const sheetShapeArray = [];
        try {
            const sheetShapeJSONArrayUnparsed = JSON.parse(this.model.get('df_shape_json'));
            sheetShapeArray.push(...sheetShapeJSONArrayUnparsed);
        }
        catch (e) {
            // Suppress error
            console.error(e);
        }
        return sheetShapeArray;
    }
    getColumnTypeJSONArray() {
        const columnTypeJSONArray = [];
        try {
            const modelColumnTypeJSONArray = JSON.parse(this.model.get('column_type_json'));
            columnTypeJSONArray.push(...modelColumnTypeJSONArray);
        }
        catch (e) {
            // Suppress error
            console.error(e);
        }
        return columnTypeJSONArray;
    }
    getSavedAnalysisNames() {
        const savedAnalysisNames = [];
        try {
            const savedAnalysisNamesJSON = JSON.parse(this.model.get('saved_analysis_names_json'));
            savedAnalysisNames.push(...savedAnalysisNamesJSON);
        }
        catch (e) {
            // Suppress error
            console.error(e);
        }
        return savedAnalysisNames;
    }
    getColumnSpreadsheetCodeJSONArray() {
        return JSON.parse(this.model.get('column_spreadsheet_code_json'));
    }
    getDfNames() {
        const dfNames = [];
        const unparsedDfNames = this.model.get('df_names_json');
        try {
            dfNames.push(...JSON.parse(unparsedDfNames)['df_names']);
            // And then we extend it to the length of the number of sheets,
            // as the dfNames sometimes aren't pulled correctly!
            const modelSheetJSONArray = this.getSheetJSONArray();
            for (let i = dfNames.length; i < modelSheetJSONArray.length; i++) {
                dfNames.push(`df${i + 1}`);
            }
        }
        catch (e) {
            // Suppress error
            console.error(e);
        }
        return dfNames;
    }
    getCodeJSON() {
        const codeJSON = {
            imports: '# No imports',
            code: ['# No code has been written yet!', 'pass']
        };
        const unparsedCodeJSON = this.model.get('code_json');
        try {
            codeJSON['imports'] = JSON.parse(unparsedCodeJSON)['imports'];
            codeJSON['code'] = JSON.parse(unparsedCodeJSON)['code'];
        }
        catch (e) {
            // Suppress error
            console.error(e);
        }
        return codeJSON;
    }
    getAnalysisName() {
        return this.model.get('analysis_name');
    }
    getColumnFilters() {
        return JSON.parse(this.model.get('column_filters_json'));
    }
    getTutorialMode() {
        return this.model.get('tutorial_mode');
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any, @typescript-eslint/explicit-module-boundary-types
    handleMessage(message) {
        /*
          This route handles the messages sent from the Python widget
        */
        var _a, _b, _c;
        const model_id = this.model.model_id;
        const mito = (_a = window.mitoMap) === null || _a === void 0 ? void 0 : _a.get(model_id);
        if (mito === undefined) {
            console.error("Error: a message was received for a mito instance that does not exist!");
            return;
        }
        console.log("Got a message, ", message);
        if (message.event === 'update_sheet') {
            console.log("Updating sheet.");
            mito.setState(() => {
                return {
                    sheetJSONArray: this.getSheetJSONArray(),
                    columnSpreadsheetCodeJSONArray: this.getColumnSpreadsheetCodeJSONArray(),
                    dfNames: this.getDfNames(),
                    sheetShapeArray: this.getSheetShapeArray(),
                    savedAnalysisNames: this.getSavedAnalysisNames(),
                    columnFiltersArray: this.getColumnFilters(),
                    columnTypeJSONArray: this.getColumnTypeJSONArray(),
                    loading: false,
                    tutorialMode: this.getTutorialMode(),
                };
            }, () => {
                // then recalculate the header height to make sure all headers are visible
                gridStyling_1.calculateAndSetHeaderHeight(model_id);
            });
        }
        else if (message.event === 'update_code') {
            console.log('Updating code.');
            (_b = window.commands) === null || _b === void 0 ? void 0 : _b.execute('write-code-to-cell', {
                analysisName: this.getAnalysisName(),
                codeJSON: this.getCodeJSON()
            });
            mito.setState({
                loading: false
            });
        }
        else if (message.event === 'edit_error') {
            console.log("Updating edit error.");
            mito.setState({
                modalInfo: { type: Mito_2.ModalEnum.Error },
                errorJSON: message,
                loading: false
            });
        }
        else if (message.event === 'api_response') {
            // We get the MitoAPI associated with this Mito instance, and add to it's unconsumed queue
            const mitoAPI = (_c = window.mitoAPIMap) === null || _c === void 0 ? void 0 : _c.get(model_id);
            mitoAPI === null || mitoAPI === void 0 ? void 0 : mitoAPI.receiveResponse(message);
        }
    }
}
exports.ExampleView = ExampleView;
//# sourceMappingURL=widget.js.map